taskRT: Data on reaction times for various tasks and topics

taskRTR Documentation

Data on reaction times for various tasks and topics

Description

A demonstration 3 x 4 two-way table composed of reaction times for tasks varying in difficulty, with content on different topics.

Format

A matrix of 3 rows and 4 columns, where the rows are the task difficulty levels and the columns are the the topics. The cell values are average reaction times (in sec.). The matrix has a responseName attribute, "RT"

Examples

data(taskRT)
twoway(taskRT)
twoway(taskRT, method="median")

twoway documentation built on July 21, 2026, 5:09 p.m.

Related to taskRT in twoway...