Learn R Programming

twoway (version 0.7.0)

as.twoway: Create an initial twoway object representing the data before fitting

Description

Create an initial twoway object representing the data before fitting

Method for matrix input

Usage

as.twoway(x, ...)

# S3 method for matrix as.twoway( x, ..., name = deparse(substitute(x)), responseName = name, varNames = names(dimnames(x)) )

Value

An object of class c("twoway") with all effects(roweff, coleff, overall) set to zero, and method="Initial"

Arguments

x

a numeric matrix or numeric data frame with rownames

...

other arguments, unused here

name

Name of the data matrix

responseName

Name of the response variable

varNames

Names of the row and column variables

Author

Richard M. Heiberger

Examples

Run this code
data(taskRT)
as.twoway(taskRT)

Run the code above in your browser using DataLab